@@ -1,12 +1,13 @@
 #!/bin/bash
 
+unset LDFLAGS
+
 cd ../fortran/build_help
-gfortran -o sizes -fopenmp omp_sizes.f90
+$FC -o sizes -fopenmp omp_sizes.f90
 python sub_sizes.py
 
 cd ..
-gfortran -E ompgen.F90 -fopenmp -cpp -o omp.f90
-#f2py *.f90 -m _wrffortran -h wrffortran.pyf --overwrite-signature
+$FC -E ompgen.F90 -fopenmp -cpp -o omp.f90
 cd ..
 
 python setup.py clean --all
